==> testops-api-1.0.1.tar.gz: testops-api-1.0.1/docs/ExecutionTestSuiteApi.md <==
# testops_api.ExecutionTestSuiteApi

All URIs are relative to *https://testops.katalon.io*

Method | HTTP request | Description
------------- | ------------- | -------------
[**get7**](ExecutionTestSuiteApi.md#get7) | **GET** /api/v1/execution-test-suites/{id} | Returns an Execution Test Suite detail.


# **get7**
> ExecutionTestSuiteResource get7(id)

Returns an Execution Test Suite detail.

### Example

* Basic Authentication (basicScheme):
```python
import time
import testops_api
from testops_api.api import execution_test_suite_api
from testops_api.model.execution_test_suite_resource import ExecutionTestSuiteResource
from pprint import pprint
# Defining the host is optional and defaults to https://testops.katalon.io
# See configuration.py for a list of all supported configuration parameters.
configuration = testops_api.Configuration(
    host = "https://testops.katalon.io"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicScheme
configuration = testops_api.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)

# Enter a context with an instance of the API client
with testops_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = execution_test_suite_api.ExecutionTestSuiteApi(api_client)
    id = "id_example" # str | 

    # example passing only required values which don't have defaults set
    try:
        # Returns an Execution Test Suite detail.
        api_response = api_instance.get7(id)
        pprint(api_response)
    except testops_api.ApiException as e:
        print("Exception when calling ExecutionTestSuiteApi->get7: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **str**|  |

### Return type

[**ExecutionTestSuiteResource**](ExecutionTestSuiteResource.md)

### Authorization

[basicScheme](../README.md#basicScheme)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: */*

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> testops-api-1.0.2.tar.gz: testops-api-1.0.2/docs/ExecutionTestSuiteApi.md <==
# testops_api.ExecutionTestSuiteApi

All URIs are relative to *http://localhost:8443*

Method | HTTP request | Description
------------- | ------------- | -------------
[**get17**](ExecutionTestSuiteApi.md#get17) | **GET** /api/v1/execution-test-suites/{id} | Returns an Execution Test Suite detail.


# **get17**
> ExecutionTestSuiteResource get17(id)

Returns an Execution Test Suite detail.

### Example

* Basic Authentication (basicScheme):
```python
import time
import testops_api
from testops_api.api import execution_test_suite_api
from testops_api.model.execution_test_suite_resource import ExecutionTestSuiteResource
from pprint import pprint
# Defining the host is optional and defaults to http://localhost:8443
# See configuration.py for a list of all supported configuration parameters.
configuration = testops_api.Configuration(
    host = "http://localhost:8443"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicScheme
configuration = testops_api.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)

# Enter a context with an instance of the API client
with testops_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = execution_test_suite_api.ExecutionTestSuiteApi(api_client)
    id = "id_example" # str | 

    # example passing only required values which don't have defaults set
    try:
        # Returns an Execution Test Suite detail.
        api_response = api_instance.get17(id)
        pprint(api_response)
    except testops_api.ApiException as e:
        print("Exception when calling ExecutionTestSuiteApi->get17: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **str**|  |

### Return type

[**ExecutionTestSuiteResource**](ExecutionTestSuiteResource.md)

### Authorization

[basicScheme](../README.md#basicScheme)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: */*

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
